@@ -132,7 +132,7 @@ func main() {
 	backupCmd.Flag("wait", "Wait for the backup to finish").
 		Short('w').
 		BoolVar(&backupOptions.wait)
-	backupCmd.Flag("list-files", "Shows the list of files per node (external backup only)").
+	backupCmd.Flag("list-files", "Shows the list of files per node to copy (only for external backups)").
 		Short('l').
 		BoolVar(&backupOptions.externList)
 
@@ -170,6 +170,8 @@ func main() {
 		StringVar(&restore.pitrBase)
 	restoreCmd.Flag("ns", `Namespaces to restore (e.g. "db1.*,db2.collection2"). If not set, restore all ("*.*")`).
 		StringVar(&restore.ns)
+	restoreCmd.Flag("with-users-and-roles", "Includes users and roles for selected database (--ns flag)").
+		BoolVar(&restore.usersAndRoles)
 	restoreCmd.Flag("wait", "Wait for the restore to finish.").
 		Short('w').
 		BoolVar(&restore.wait)
@@ -382,7 +384,7 @@ func main() {
 	// we don't need pbm connection if it is `pbm describe-restore -c ...`
 	// or `pbm restore-finish `
 	if describeRestoreOpts.cfg == "" && finishRestore.cfg == "" {
-		conn, err = connect.Connect(ctx, *mURL, &connect.ConnectOptions{AppName: "pbm-ctl"})
+		conn, err = connect.Connect(ctx, *mURL, "pbm-ctl")
 		if err != nil {
 			exitErr(errors.Wrap(err, "connect to mongodb"), pbmOutF)
 		}
@@ -431,7 +433,7 @@ func main() {
 	case cleanupCmd.FullCommand():
 		out, err = doCleanup(ctx, conn, pbm, &cleanupOpts)
 	case logsCmd.FullCommand():
-		out, err = runLogs(ctx, conn, &logs)
+		out, err = runLogs(ctx, conn, &logs, pbmOutF)
 	case statusCmd.FullCommand():
 		out, err = status(ctx, conn, pbm, *mURL, statusOpts, pbmOutF == outJSONpretty)
 	case describeRestoreCmd.FullCommand():
@@ -496,7 +498,7 @@ func exitErr(e error, f outFormat) {
 	os.Exit(1)
 }
 
-func runLogs(ctx context.Context, conn connect.Client, l *logsOpts) (fmt.Stringer, error) {
+func runLogs(ctx context.Context, conn connect.Client, l *logsOpts, f outFormat) (fmt.Stringer, error) {
 	r := &log.LogRequest{}
 
 	if l.node != "" {
@@ -535,7 +537,7 @@ func runLogs(ctx context.Context, conn connect.Client, l *logsOpts) (fmt.Stringe
 	}
 
 	if l.follow {
-		err := followLogs(ctx, conn, r, r.Node == "", l.extr)
+		err := followLogs(ctx, conn, r, r.Node == "", l.extr, f)
 		return nil, err
 	}
 
@@ -561,9 +563,17 @@ func runLogs(ctx context.Context, conn connect.Client, l *logsOpts) (fmt.Stringe
 	return o, nil
 }
 
-func followLogs(ctx context.Context, conn connect.Client, r *log.LogRequest, showNode, expr bool) error {
+func followLogs(ctx context.Context, conn connect.Client, r *log.LogRequest, showNode, expr bool, f outFormat) error {
 	outC, errC := log.Follow(ctx, conn, r, false)
 
+	var enc *json.Encoder
+	if f == outJSON {
+		enc = json.NewEncoder(os.Stdout)
+	} else if f == outJSONpretty {
+		enc = json.NewEncoder(os.Stdout)
+		enc.SetIndent("", "  ")
+	}
+
 	for {
 		select {
 		case entry, ok := <-outC:
@@ -571,7 +581,14 @@ func followLogs(ctx context.Context, conn connect.Client, r *log.LogRequest, sho
 				return nil
 			}
 
-			fmt.Println(entry.Stringify(tsUTC, showNode, expr))
+			if f == outJSON || f == outJSONpretty {
+				err := enc.Encode(entry)
+				if err != nil {
+					exitErr(errors.Wrap(err, "encode output"), f)
+				}
+			} else {
+				fmt.Println(entry.Stringify(tsUTC, showNode, expr))
+			}
 		case err, ok := <-errC:
 			if !ok {
 				return nil
