@@ -141,11 +141,11 @@ install_golang() {
     elif [ x"$ARCH" = "xaarch64" ]; then
         GO_ARCH="arm64"
     fi
-    wget https://golang.org/dl/go1.19.linux-${GO_ARCH}.tar.gz -O /tmp/golang1.19.tar.gz
-    tar --transform=s,go,go1.19, -zxf /tmp/golang1.19.tar.gz
+    wget https://go.dev/dl/go1.22.3.linux-${GO_ARCH}.tar.gz -O /tmp/go1.22.tar.gz
+    tar --transform=s,go,go1.22, -zxf /tmp/go1.22.tar.gz
     rm -rf /usr/local/go*
-    mv go1.19 /usr/local/
-    ln -s /usr/local/go1.19 /usr/local/go
+    mv go1.22 /usr/local/
+    ln -s /usr/local/go1.22 /usr/local/go
 }
 
 install_deps() {
