@@ -21,10 +21,10 @@ func (*Blackhole) Save(_ string, data io.Reader, _ int64) error {
 	return err
 }
 
-func (*Blackhole) List(_, _ string) ([]storage.FileInfo, error)        { return []storage.FileInfo{}, nil }
-func (*Blackhole) Delete(_ string) error                               { return nil }
-func (*Blackhole) FileStat(_ string) (inf storage.FileInfo, err error) { return }
-func (*Blackhole) Copy(_, _ string) error                              { return nil }
+func (*Blackhole) List(_, _ string) ([]storage.FileInfo, error) { return []storage.FileInfo{}, nil }
+func (*Blackhole) Delete(_ string) error                        { return nil }
+func (*Blackhole) FileStat(_ string) (storage.FileInfo, error)  { return storage.FileInfo{}, nil }
+func (*Blackhole) Copy(_, _ string) error                       { return nil }
 
 // NopReadCloser is a no operation ReadCloser
 type NopReadCloser struct{}
