@@ -130,7 +130,7 @@ type Client interface {
 }
 
 func NewClient(ctx context.Context, uri string) (Client, error) {
-	conn, err := connect.Connect(ctx, uri, nil)
+	conn, err := connect.Connect(ctx, uri, "sdk")
 	if err != nil {
 		return nil, err
 	}
